Learn R Programming

ReliabilityTheory (version 0.1.5)

ReliabilityTheory-package: Structural Reliability Theory Toolbox

Description

A collection of tools for working structural reliability problems, such as catalogues of system signatures and Bayesian inferential functions.

Arguments

Details

Package:
ReliabilityTheory
Type:
Package
Version:
0.1.5
Date:
2015-10-13
License:
GPL-2 | GPL-3
LazyLoad:
yes

References

Aslett, L. J. M. (2012), MCMC for Inference on Phase-type and Masked System Lifetime Models, PhD Thesis, Trinity College Dublin.

Samaniego, F. J. (2007), System Signatures and Their Applications in Engineering Reliability, Springer.