# Find the expected lifetime of two component series system
expectedSystemLifetimeExp(graph.formula(s -- 1 -- 2 -- t))
# Find the expected lifetime of two component series system using it's signature directly
expectedSignatureLifetimeExp(c(1,0))
# Find the expected lifetime of two component parallel system
expectedSystemLifetimeExp(graph.formula(s -- 1:2 -- t))
# Find the expected lifetime of two component parallel system using it's signature directly
expectedSignatureLifetimeExp(c(0,1))
Run the code above in your browser using DataLab