maskedInferenceEXCHCustom(t, signature, cdfComp, pdfComp, rParmGivenData, rCompGivenParm, startCompParm, startHypParm, iter, ...)function(y, parametersm, ...)
function(y, parameters, ...)
function(y, ...)
This must return the new parameters as a 2 item list: the first item being the hyperprior parameters drawn in the same named vector format and order as startHypPriorParm; the second item being a list of component lifetime parameters drawn in the same named vector format and order as startCompParm.
function(parameters, t, censoring, ...)
where censoring is -1 for left censoring, 0 for exact observations and 1 for right censoring.
t) of named parameters for the component lifetime distribution. The order within each named vector should match the order expected for the parameters argument in the user defined functions above.
startParm argument is returned.If a list of signature vectors is provided above, then a list is returned containing three items:
startCompParm argument.startHypPriorParm argument.The arguments of the function are the prerequisites described in Algorithm 6.2 of Aslett (2012). The interested user is advised to inspect the source code of this package at the file MaskedLifetimeInference_Exponential.R for an example of its usage, which may be seen in the function maskedInferenceEXCHExponential defined there, together with the associated user-definied functions above it.
computeSystemSignature
# Please inspect the source of this package, file MaskedLifetimeInference_Exponential.R
# for example usage (see details section)
Run the code above in your browser using DataLab