maskedInferenceIIDCustom(t, signature, cdfComp, pdfComp, rParmGivenData, rCompGivenParm, startParm, iter, ...)function(y, parametersm, ...)
function(y, parameters, ...)
function(y, ...)
This must return the parameters in the same order named vector format as used for startParm.
function(parameters, t, censoring, ...)
where censoring is -1 for left censoring, 0 for exact observations and 1 for right censoring.
parameters argument in the user defined functions above.
startParm argument is returned.If a list of signature vectors is provided above, then a list is returned containing two items:
startParm argument.The arguments of the function are the prerequisites described in Algorithm 6.2 of Aslett (2012). The interested user is advised to inspect the source code of this package at the file MaskedLifetimeInference_Exponential.R for an example of its usage, which may be seen in the function maskedInferenceIIDExponential defined there, together with the associated user-definied functions above it.
computeSystemSignature
# Please inspect the source of this package, file MaskedLifetimeInference_Exponential.R
# for example usage (see details section)
Run the code above in your browser using DataLab