sccsO4: Catalogue of Simply Connected Coherent Systems of Order 4
Description
This data sets provides a catalogue of the network graph, signature and minimal cut-sets of all simply connected coherent systems of order 4.
Format
A list object, one item for each such systems. Each item is itself a list, with the elements $graph, $cutsets and $signature.Source
Derived in the thesis Aslett (2012).References
Aslett, L. J. M. (2012), MCMC for Inference on Phase-type and Masked System Lifetime Models, PhD Thesis, Trinity College Dublin.